@@ -18,6 +18,13 @@ class ResultModel:
         if self.data:
             if hasattr(self.data, "to_dict"):
                 data_dict = self.data.to_dict()
+            elif isinstance(self.data, list):
+                data_dict = []
+                for item in self.data:
+                    if hasattr(item, "to_dict"):
+                        data_dict.append(item.to_dict())
+                    else:
+                        data_dict.append(item)
         return {
             "success": self.success,
             "data": data_dict,
